@@ -54,15 +54,57 @@ use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-# Require all the modules now to avoid unexpected failures in the middle of release.
-use Dist::Zilla::Plugin::Hook 0.005;    # We need Hook::PrereqSource.
-use IPC::System::Simple qw{};
-use Path::Tiny          qw{};
-use Perl::Version       qw{};
+#   Require all the modules explicitly now to avoid unexpected failures in the middle of release.
+use IPC::System::Simple ();
+use Path::Tiny          ();
+use Perl::Version       ();
+
+#   Explicitly require all the plugins to let them appear in the metadata.
+use Dist::Zilla::Plugin::Hook                       0.005   ();   # We need Hook::PrereqSource.
+use Dist::Zilla::Plugin::GatherFromManifest                 ();
+use Dist::Zilla::Plugin::Manifest::Write                    ();
+use Dist::Zilla::Plugin::OurPkgVersion                      ();
+use Dist::Zilla::Plugin::SurgicalPodWeaver                  ();
+use Dist::Zilla::Plugin::Test::EOL                          ();
+use Dist::Zilla::Plugin::Test::NoTabs                       ();
+use Dist::Zilla::Plugin::MojibakeTests                      ();
+use Dist::Zilla::Plugin::Test::Compile                      ();
+use Dist::Zilla::Plugin::Test::Version                      ();
+use Dist::Zilla::Plugin::Test::NewVersion                   ();
+use Dist::Zilla::Plugin::Test::MinimumVersion               ();
+use Dist::Zilla::Plugin::Test::Perl::Critic                 ();
+use Dist::Zilla::Plugin::PodSyntaxTests                     ();
+use Dist::Zilla::Plugin::PodCoverageTests                   ();
+use Dist::Zilla::Plugin::Test::PodSpelling                  ();
+use Dist::Zilla::Plugin::Test::Pod::No404s                  ();
+use Dist::Zilla::Plugin::MetaTests                          ();
+use Dist::Zilla::Plugin::Test::CPAN::Meta::JSON             ();
+use Dist::Zilla::Plugin::Test::CPAN::Changes                ();
+use Dist::Zilla::Plugin::Test::DistManifest                 ();
+use Dist::Zilla::Plugin::Test::Kwalitee                     ();
+use Dist::Zilla::Plugin::MinimumPerl                        ();
+use Dist::Zilla::Plugin::AutoPrereqs                        ();
+use Dist::Zilla::Plugin::Prereqs::AuthorDeps                ();
+use Dist::Zilla::Plugin::CheckPrereqsIndexed                ();
+use Dist::Zilla::Plugin::MetaProvides::Package              ();
+use Dist::Zilla::Plugin::MetaResources::Template            ();
+use Dist::Zilla::Plugin::MetaYAML                           ();
+use Dist::Zilla::Plugin::MetaJSON                           ();
+use Dist::Zilla::Plugin::ModuleBuildTiny                    ();
+use Dist::Zilla::Plugin::CheckExtraTests                    ();
+use Dist::Zilla::Plugin::CheckChangesHasContent             ();
+use Dist::Zilla::Plugin::TestRelease                        ();
+use Dist::Zilla::Plugin::ConfirmRelease                     ();
+use Dist::Zilla::Plugin::FakeRelease                        ();
+use Dist::Zilla::Plugin::UploadToCPAN                       ();
+use Dist::Zilla::Plugin::NextRelease                        ();
+
+#   One more implicitly required module.
+use Pod::Weaver::PluginBundle::Author::VDB ();
 
 has minimum_perl => (
     is          => 'ro',
@@ -152,7 +194,8 @@ sub configure {
 
         [ 'OurPkgVersion' ],
         [ 'SurgicalPodWeaver' => {
-            'replacer' => 'replace_with_comment',
+            'replacer'      => 'replace_with_comment',
+            'config_plugin' => '@Author::VDB',
         } ],
 
         #
@@ -476,7 +519,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version 0.003, released on 2015-08-09 19:26 UTC.
+Version 0.004, released on 2015-08-09 22:12 UTC.
 
 =head1 WHAT?
 
